@@ -7,18 +7,10 @@
 #include <QIcon>
 #include <QWidget>
 #include <QObject>
-#include <QHash>
 #include <QWidget>
 
 class TrayWidget;
 namespace tray {
-
-enum Protocol {
-    UNKNOWN = 0,
-    XEMBED,
-    SNI
-};
-
 class AbstractTrayProtocolHandler;
 class AbstractTrayProtocol : public QObject
 {
@@ -29,9 +21,6 @@ public:
 
 Q_SIGNALS:
     void trayCreated(QPointer<AbstractTrayProtocolHandler> handler);
-
-protected:
-    inline static QHash<uint, enum Protocol> registeredMap;
 };
 
 class AbstractTrayProtocolHandler : public QObject
