@@ -16,7 +16,6 @@
 #include <DSwitchButton>
 #include <DListView>
 #include <DSpinner>
-#include <DApplicationHelper>
 
 #include <QBoxLayout>
 #include <QStandardItemModel>
@@ -75,7 +74,7 @@ BluetoothAdapterItem::BluetoothAdapterItem(Adapter *adapter, QWidget *parent)
     , m_otherDeviceListView(new PluginListView(this))
     , m_otherDeviceModel(new QStandardItemModel(m_otherDeviceListView))
     , m_refreshBtn(new CommonIconButton(this))
-    , m_bluetoothInter(new DBusBluetooth("com.deepin.daemon.Bluetooth", "/com/deepin/daemon/Bluetooth", QDBusConnection::sessionBus(), this))
+    , m_bluetoothInter(new DBusBluetooth("org.deepin.dde.Bluetooth1", "/org/deepin/dde/Bluetooth1", QDBusConnection::sessionBus(), this))
     , m_showUnnamedDevices(false)
     , m_stateBtnEnabled(true)
     , m_adapterSwitchEnabled(true)
@@ -296,12 +295,14 @@ void BluetoothAdapterItem::onDeviceRemoved(const Device *device)
     }
 
     QStandardItemModel *sourceModel = m_deviceItems.value(device)->standardItem()->model();
-    for (int rowIndex = 0; rowIndex < sourceModel->rowCount(); ++rowIndex) {
-        QModelIndex index = sourceModel->index(rowIndex, 0);
-        auto item = dynamic_cast<PluginStandardItem *>(sourceModel->itemFromIndex(index));
-        if (item == m_deviceItems.value(device)->standardItem()) {
-            sourceModel->removeRow(rowIndex);
-            break;
+    if (sourceModel) {
+        for (int rowIndex = 0; rowIndex < sourceModel->rowCount(); ++rowIndex) {
+            QModelIndex index = sourceModel->index(rowIndex, 0);
+            auto item = dynamic_cast<PluginStandardItem *>(sourceModel->itemFromIndex(index));
+            if (item == m_deviceItems.value(device)->standardItem()) {
+                sourceModel->removeRow(rowIndex);
+                break;
+            }
         }
     }
 
@@ -347,7 +348,6 @@ void BluetoothAdapterItem::initUi()
     DFontSizeManager::instance()->bind(m_adapterLabel->label(), DFontSizeManager::T4);
 
     QVBoxLayout *mainLayout = new QVBoxLayout(this);
-    mainLayout->setMargin(0);
     mainLayout->setSpacing(0);
     mainLayout->setContentsMargins(0, 0, 0, 0);
 
@@ -358,7 +358,6 @@ void BluetoothAdapterItem::initUi()
     m_myDeviceListView->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     m_myDeviceListView->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     QVBoxLayout *myDeviceLayout = new QVBoxLayout(m_myDeviceWidget);
-    myDeviceLayout->setMargin(0);
     myDeviceLayout->setSpacing(0);
     m_myDeviceLabel->setContentsMargins(10, 0, 0, 2);
     DFontSizeManager::instance()->bind(m_myDeviceLabel, DFontSizeManager::T10);
@@ -398,9 +397,9 @@ void BluetoothAdapterItem::initUi()
 
 void BluetoothAdapterItem::initConnect()
 {
-    m_scanTimer->setInterval(DConfigHelper::instance()->getConfig("org.deepin.dde.dock", "org.deepin.dde.dock.plugin.bluetooth", "", "scanInterval", 10).toInt() * 1000);
+    m_scanTimer->setInterval(DConfigHelper::instance()->getConfig("org.deepin.dde.dock", "org.deepin.dde.dock.plugin.bluetooth", "", "scanInterval", 5).toInt() * 1000);
     DConfigHelper::instance()->bind("org.deepin.dde.dock", "org.deepin.dde.dock.plugin.bluetooth", "", this, "scanInterval", [this] (const QString&, const QVariant&, QObject*) {
-        m_scanTimer->setInterval(DConfigHelper::instance()->getConfig("org.deepin.dde.dock", "org.deepin.dde.dock.plugin.bluetooth", "", "scanInterval", 10).toInt() * 1000);
+        m_scanTimer->setInterval(DConfigHelper::instance()->getConfig("org.deepin.dde.dock", "org.deepin.dde.dock.plugin.bluetooth", "", "scanInterval", 5).toInt() * 1000);
     });
     connect(m_scanTimer, &QTimer::timeout, this, [this] {
         if (isVisible())
@@ -485,6 +484,8 @@ void BluetoothAdapterItem::setUnnamedDevicesVisible(bool isShow)
             if (deviceItem && deviceItem->device() && deviceItem->device()->name().isEmpty()) {
                 PluginStandardItem *dListItem = deviceItem->standardItem();
                 QStandardItemModel *model = i.value()->standardItem()->model();
+                if (!model)
+                    continue;
                 QModelIndex index = model->indexFromItem(dListItem);
                 if (!index.isValid()) {
                     model->insertRow(((connectCount > -1 && connectCount < m_deviceItems.count()) ? connectCount : 0), dListItem);
@@ -503,6 +504,8 @@ void BluetoothAdapterItem::setUnnamedDevicesVisible(bool isShow)
                 && (Device::StateConnected != deviceItem->device()->state() || !deviceItem->device()->connecting())) {
             PluginStandardItem *dListItem = deviceItem->standardItem();
             QStandardItemModel *model = i.value()->standardItem()->model();
+            if (!model)
+                continue;
             QModelIndex index = model->indexFromItem(dListItem);
             if (index.isValid()) {
                 model->takeRow(index.row());
