@@ -27,8 +27,8 @@ SidebarCalendarWidget::SidebarCalendarWidget(RegionFormat *regionFormat, QWidget
     , m_keyWidget(new QWidget(this))
     , m_keyLayout(new QGridLayout)
     , m_dateLabel(new QLabel(this))
-    , m_nextPage(new DIconButton(this))
-    , m_previousPage(new DIconButton(this))
+    , m_nextPage(new DToolButton(this))
+    , m_previousPage(new DToolButton(this))
     , m_firstday(Qt::Sunday)
     , m_dateTitleWidget(new DateTitleWidget(this))
     , m_weekLabel(new DLabel(this))
