@@ -85,7 +85,7 @@ public:
             auto mouseEvent = dynamic_cast<QMouseEvent*>(event);
             if (mouseEvent && mouseEvent->button() == Qt::RightButton) {
                 // 右键事件本身不处理, 转发给target
-                auto copy = new QMouseEvent(*mouseEvent);
+                auto copy = mouseEvent->clone();
                 qApp->postEvent(m_target, copy);
                 event->accept();
                 return true;
@@ -164,7 +164,7 @@ QMenu *QuickPluginItem::pluginContextMenu()
     }
 
     m_menu->setAttribute(Qt::WA_TranslucentBackground, true);
-    // FIXME: qt5integration drawMenuItemBackground will draw a background event is's transparent
+
     auto pa = m_menu->palette();
     pa.setColor(QPalette::ColorRole::Window, Qt::transparent);
     m_menu->setPalette(pa);
@@ -215,4 +215,3 @@ void QuickPluginItem::requestActiveState()
         }
     }
 }
-
